//
//  tank
//
//  Import and Playlist Daemon for autoradio project
//
//
//  Copyright (C) 2017-2019 Christian Pointner <equinox@helsinki.at>
//
//  This file is part of tank.
//
//  tank is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  any later version.
//
//  tank is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with tank. If not, see <http://www.gnu.org/licenses/>.
//

package v1

import (
	"errors"

	"gitlab.servus.at/autoradio/tank/importer"
	"gitlab.servus.at/autoradio/tank/store"
)

// common
var (
	ErrNotFlowJSUpload            = errors.New("this is not a flow.js upload")
	ErrFlowJSChunkAlreadUploading = errors.New("chunk is already uploading or done")
	ErrFileVanished               = errors.New("the file vanished from the store while preparing the import")
)

type ErrorResponse struct {
	Error  string      `json:"error,omitempty"`
	Detail interface{} `json:"detail,omitempty"`
}

// Shows
type ShowsListing struct {
	Shows store.Shows `json:"results"`
}

// Imports
type JobsListing struct {
	Jobs importer.Jobs `json:"results"`
}

// Files
type FilesListing struct {
	Files store.Files `json:"results"`
}

type FileCreateRequest struct {
	SourceURI string `json:"source-uri"`
}

type FileUsageListing struct {
	Usage struct {
		Playlists store.Playlists `json:"playlists"`
	} `json:"results"`
}

type FileImportLogs struct {
	Logs store.ImportLogs `json:"results"`
}

// Playlists
type PlaylistsListing struct {
	Playlists store.Playlists `json:"results"`
}
