//
//  tank
//
//  Import and Playlist Daemon for autoradio project
//
//
//  Copyright (C) 2017-2019 Christian Pointner <equinox@helsinki.at>
//
//  This file is part of tank.
//
//  tank is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  any later version.
//
//  tank is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with tank. If not, see <http://www.gnu.org/licenses/>.
//

package main

import (
	"errors"
	"os"

	"gitlab.servus.at/autoradio/tank/auth"
	"gitlab.servus.at/autoradio/tank/importer"
	"gitlab.servus.at/autoradio/tank/store"
	"gopkg.in/yaml.v2"
)

type CorsConfig struct {
	AllowedOrigins     []string `json:"allowed-origins" yaml:"allowed-origins" toml:"allowed-origins"`
	AllowedMethods     []string `json:"allowed-methods" yaml:"allowed-methods" toml:"allowed-methods"`
	AllowedHeaders     []string `json:"allowed-headers" yaml:"allowed-headers" toml:"allowed-headers"`
	ExposedHeaders     []string `json:"exposed-headers" yaml:"exposed-headers" toml:"exposed-headers"`
	MaxAge             int      `json:"max-age" yaml:"max-age" toml:"max-age"`
	AllowCredentials   bool     `json:"allow-credentials" yaml:"allow-credentials" toml:"allow-credentials"`
	OptionsPassthrough bool     `json:"options-passthrough" yaml:"options-passthrough" toml:"options-passthrough"`
	Debug              bool     `json:"debug" yaml:"debug" toml:"debug"`
}

type Config struct {
	Store    store.Config    `json:"store" yaml:"store" toml:"store"`
	Importer importer.Config `json:"importer" yaml:"importer" toml:"importer"`
	Auth     *auth.Config    `json:"auth" yaml:"auth" toml:"auth"`
	Cors     *CorsConfig     `json:"cors" yaml:"cors" toml:"cors"`
}

func (c *Config) ExpandEnv() {
	c.Store.ExpandEnv()
	c.Importer.ExpandEnv()
	if c.Auth != nil {
		c.Auth.ExpandEnv()
	}
	if c.Cors != nil {
		// TODO: implement this...
	}
}

func ReadConfig(configfile string) (conf *Config, err error) {
	var f *os.File
	if f, err = os.Open(configfile); err != nil {
		err = errors.New("error opening config file(" + configfile + "): " + err.Error())
		return
	}
	defer f.Close()

	conf = &Config{}
	decoder := yaml.NewDecoder(f)
	decoder.SetStrict(true)
	if err = decoder.Decode(conf); err != nil {
		err = errors.New("error opening config file(" + configfile + "): " + err.Error())
		return
	}
	conf.ExpandEnv()
	infoLog.Printf("successfully read config file (%s)", configfile)
	return
}
