//
//  tank
//
//  Import and Playlist Daemon for autoradio project
//
//
//  Copyright (C) 2017-2019 Christian Pointner <equinox@helsinki.at>
//
//  This file is part of tank.
//
//  tank is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  any later version.
//
//  tank is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with tank. If not, see <http://www.gnu.org/licenses/>.
//

package main

import (
	"net"
	"net/http"
	"time"

	"github.com/gin-gonic/gin"
	"github.com/rs/cors"
	apiV1 "gitlab.servus.at/autoradio/tank/api/v1"
	"gitlab.servus.at/autoradio/tank/auth"
	"gitlab.servus.at/autoradio/tank/importer"
	"gitlab.servus.at/autoradio/tank/store"
	"gitlab.servus.at/autoradio/tank/ui"
)

const (
	WebUIPathPrefix = "/ui/"
	WebAuthPrefix   = "/auth/"
	WebAPIv1Prefix  = "/api/v1/"
)

func runWeb(ln net.Listener, st *store.Store, im *importer.Importer, cc *CorsConfig) error {
	gin.SetMode(gin.ReleaseMode)

	r := gin.New()
	r.Use(gin.Recovery())
	r.Use(gin.Logger())
	r.HandleMethodNotAllowed = true

	r.GET("/", func(c *gin.Context) { c.Redirect(http.StatusSeeOther, WebUIPathPrefix) })
	r.StaticFS(WebUIPathPrefix, ui.Assets)

	apiV1.InstallHTTPHandler(r.Group(WebAPIv1Prefix), st, im, infoLog, errLog, dbgLog)
	auth.InstallHTTPHandler(r.Group(WebAuthPrefix))

	srv := &http.Server{
		Handler:      r,
		WriteTimeout: 12 * time.Hour,
		ReadTimeout:  12 * time.Hour,
	}

	if cc != nil {
		c := cors.New(cors.Options{
			AllowedOrigins:     cc.AllowedOrigins,
			AllowedMethods:     cc.AllowedMethods,
			AllowedHeaders:     cc.AllowedHeaders,
			ExposedHeaders:     cc.ExposedHeaders,
			MaxAge:             cc.MaxAge,
			AllowCredentials:   cc.AllowCredentials,
			OptionsPassthrough: cc.OptionsPassthrough,
			Debug:              cc.Debug,
		})
		srv.Handler = c.Handler(r)
	}

	infoLog.Printf("web: listening on %s", ln.Addr())
	return srv.Serve(ln)
}
